@@ -234,9 +234,15 @@ xsltDocumentFunction(xmlXPathParserContextPtr ctxt, int nargs)
                 valuePush(ctxt, xmlXPathNewNodeSet(NULL));
             } else {
                 doc = xsltLoadDocument(tctxt, URI);
-                if (doc == NULL)
-                    valuePush(ctxt, xmlXPathNewNodeSet(NULL));
-                else {
+                if (doc == NULL) {
+		    if ((xmlStrEqual(URI, BAD_CAST "")) ||
+			(xmlStrEqual(tctxt->style->doc->URL, URI))) {
+			valuePush(ctxt, xmlXPathNewNodeSet(
+				    (xmlNodePtr)tctxt->style->doc));
+		    } else {
+			valuePush(ctxt, xmlXPathNewNodeSet(NULL));
+		    }
+		} else {
                     /* TODO: use XPointer of HTML location for fragment ID */
                     /* pbm #xxx can lead to location sets, not nodesets :-) */
                     valuePush(ctxt,
