@@ -246,6 +246,28 @@ function genReadme(bname, ver, file)
 	f.WriteLine("  The directory called 'util' contains various programs which count as a");
 	f.WriteLine("part of " + bname + ".");
 	f.WriteBlankLines(1);
+	f.WriteLine("  If you plan to develop your own programme, in C, which uses " + bname + ", then");
+	f.WriteLine("you should know what to do with the files in the binary package. If you don't,");
+	f.WriteLine("know this, then please, please do some research on how to use a");
+	f.WriteLine("third-party library in a C programme. The topic belongs to the very basics"); 
+	f.WriteLine("and you will not be able to do much without that knowledge.");
+	f.WriteBlankLines(1);
+	f.WriteLine("  If you wish to use " + bname + " solely through the supplied utilities, such as");
+	f.WriteLine("xmllint or xsltproc, then all you need to do is place the");
+	f.WriteLine("contents of the 'lib' and 'util' directories from the binary package in a"); 
+	f.WriteLine("directory on your disc which is mentioned in your PATH environment"); 
+	f.WriteLine("variable. You can use an existing directory which is allready in the"); 
+	f.WriteLine("path, such as 'C:\WINDOWS', or 'C:\WINNT'. You can also create a new"); 
+	f.WriteLine("directory for " + bname + " and place the files there, but be sure to modify"); 
+	f.WriteLine("the PATH environment variable and add that new directory to its list.");
+	f.WriteBlankLines(1);
+	f.WriteLine("  If you use other software which needs " + bname + ", such as Apache");
+	f.WriteLine("Web Server in certain configurations, then please consult the"); 
+	f.WriteLine("documentation of that software and see if it mentions something about");
+	f.WriteLine("how it uses " + bname + " and how it expects it to be installed. If you find");
+	f.WriteLine("nothing, then the default installation, as described in the previous"); 
+	f.WriteLine("paragraph, should be suficient.");
+	f.WriteBlankLines(1);
 	f.WriteLine("  If there is something you cannot keep for yourself, such as a problem,");
 	f.WriteLine("a cheer of joy, a comment or a suggestion, feel free to contact me using");
 	f.WriteLine("the address below.");
